@@ -2,8 +2,10 @@
 # -*- coding: utf-8 -*-
 """ Message-viewer UI for fMMS
 
-@author: Nick Leppänen Larsson <frals@frals.se>
-@license: GNU GPL
+fMMS - MMS for fremantle
+Copyright (C) 2010 Nick Leppänen Larsson <frals@frals.se>
+
+@license: GNU GPLv2, see COPYING file.
 """
 import os
 import sys
@@ -191,16 +193,12 @@ class fMMS_Viewer(hildon.Program):
 				
 
 		headerlist = self.cont.get_mms_headers(filename)
-		sender = headerlist.get('From', "").replace("/TYPE=PLMN", "")
-		sendername = self.ch.get_name_from_number(sender)
-		if sendername != None:
-			sender = sendername
-			
-          	self.window.set_title("MMS - " + str(sender))
+
 		topbox = gtk.HBox()
 		
 		if self._direction == fMMSController.MSG_DIRECTION_IN:
 			label = gtk.Label('<span foreground="#666666">From</span>')
+			sender = headerlist.get('From', "0").replace("/TYPE=PLMN", "")
 		else:
 			label = gtk.Label('<span foreground="#666666">To</span>')
 			sender = headerlist['To'].replace("/TYPE=PLMN", "")
@@ -208,7 +206,8 @@ class fMMS_Viewer(hildon.Program):
 		label.set_use_markup(True)
 		label.set_alignment(0, 0.5)
 
-		sendername = self.ch.get_name_from_number(sender)
+		senderuid = self.ch.get_uid_from_number(sender)
+		sendername = self.ch.get_displayname_from_uid(senderuid)
 		if sendername != None:
 			sender = sendername
 
